#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for Oregano -- schematic capture program.
#---( Source URL: http://gforge.lug.fi.uba.ar/frs/download.php/86/oregano-0.69.0.tar.gz
#---( Build script by R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Sunday, 16-Sept-2007


#------------------( Set Package Name & Version )


soft='oregano'
softversion='0.69.0'
packageversion='48.1'


#------------------( Check for Source File )


if [ -f $soft-$softversion.tar.gz  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Downloading it ..."
   wget -c http://gforge.lug.fi.uba.ar/frs/download.php/86/oregano-0.69.0.tar.gz
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/share


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CCFLAGS="-O2 -march=$arch -mtune=$cpu" 


#------------------( Configure, Make And Install The Software )


cd $src
sed -i -e 's/-Wall/-O2 -march=i486 -mtune=i686 -Wall/' SConstruct
sed -i -e "s/run update-mime-database', 1/run update-mime-database', 0/" SConstruct
scons install release=1 DESTDIR=$dest PREFIX=//usr
install -d $dest/usr/share/gnome/help/oregano/{C,es,fr}
install -m644 help/C/*.xml $dest/usr/share/gnome/help/oregano/C
install -m644 help/es/*.xml $dest/usr/share/gnome/help/oregano/es
install -m644 help/fr/*.xml $dest/usr/share/gnome/help/oregano/fr


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)


#------------------( Move Documentation and Icon To Correct Location )


mv $dest/usr/share/doc $dest/usr
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS COPYING NEWS README INSTALL \
  $dest/usr/doc/$soft-$softversion


#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
oregano: Oregano (Schematic capture program)
oregano:
oregano: Oregano is an application for schematic capture and simulation of
oregano: electrical circuits. The actual simulation is performed by ngSpice
oregano: or GNU Cap, which is required for simulation, but not necessary to
oregano: run the application.
oregano: 
oregano:
oregano: 
oregano:
oregano: 
EOF

#------------------( Create The Doinst.sh File)


cat <<EOF > $dest/install/doinst.sh
if [ -x /usr/bin/scrollkeeper-update ]; then
  /usr/bin/scrollkeeper-update -p /var/lib/scrollkeeper 1>/dev/null 2>/dev/null
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime 1> /dev/null 2> /dev/null
fi
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi
EOF


#------------------( Create The Desktop Menu Entry )


mkdir -p $dest/usr/share/applications
cat <<EOF > $dest/usr/share/applications/$soft.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Oregano
Comment=Schematic capture and simulation of electrical circuits
Comment[sv]=Kretsschemariting och simulering av elektriska kretsar
Comment[it]=Disegno e simulazione di circuiti elettrici
Comment[es]=Preparación de esquemáticos y simulación de circuitos eléctricos
Exec=oregano
Icon=gnome-oregano
Terminal=false
Type=Application
Categories=Education;Engineering
EOF


#------------------( Copy The Icon To The Correct Location )


mkdir -p $dest/usr/share/icons/hicolor/scalable/apps/
cp gnome-oregano.svg $dest/usr/share/icons/hicolor/scalable/apps/
rm -rf $dest/usr/share/pixmaps


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum and Check Package )


cd $buildir
zen_pkgcheck_new.pl $package.tgz
md5sum $package.tgz > $package.md5
requiredbuilder -z $package.tgz > $package.dep